@@ -8,6 +8,11 @@
  * does it submit to any jurisdiction.
  */
 
+// Disable warnings: warning #550-D: variable "__d0" was set but never used [set_but_not_used] in FD_ZERO(&r);
+#if defined(__NVCOMPILER)
+#pragma diag_suppress 550
+#endif
+
 #include <sys/types.h>  // FreeBSD: must appear before netinet/ip.h
 
 #include <arpa/inet.h>
@@ -16,7 +21,7 @@
 #include <netinet/ip.h>
 #include <netinet/tcp.h>
 #include <setjmp.h>
-#include <signal.h>
+#include <csignal>
 #include <sys/ioctl.h>
 #include <sys/socket.h>
 #include <unistd.h>
